/***
	Copyright (c) 2008-2010 CommonsWare, LLC
	
	Licensed under the Apache License, Version 2.0 (the "License"); you may
	not use this file except in compliance with the License. You may obtain
	a copy of the License at
		http://www.apache.org/licenses/LICENSE-2.0
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/

package com.commonsware.android.search;

import android.app.Activity;
import android.app.ListActivity;
import android.app.SearchManager;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

abstract public class LoremBase extends ListActivity {
	abstract ListAdapter makeMeAnAdapter(Intent intent);
	
	private static final int LOCAL_SEARCH_ID = Menu.FIRST+1;
	private static final int GLOBAL_SEARCH_ID = Menu.FIRST+2;
	TextView selection;
	ArrayList<String> items=new ArrayList<String>();
	
	@Override
	public void onCreate(Bundle icicle) {
		super.onCreate(icicle);
		setContentView(R.layout.main);
		selection=(TextView)findViewById(R.id.selection);
		
		try {
			XmlPullParser xpp=getResources().getXml(R.xml.words);
			
			while (xpp.getEventType()!=XmlPullParser.END_DOCUMENT) {
				if (xpp.getEventType()==XmlPullParser.START_TAG) {
					if (xpp.getName().equals("word")) {
						items.add(xpp.getAttributeValue(0));
					}
				}
				
				xpp.next();
			}
		}
		catch (Throwable t) {
			Toast
				.makeText(this, "Request failed: "+t.toString(), 4000)
				.show();
		}
		
		setDefaultKeyMode(DEFAULT_KEYS_SEARCH_LOCAL);
		
		onNewIntent(getIntent());
	}
	
	@Override
	public void onNewIntent(Intent intent) {
		ListAdapter adapter=makeMeAnAdapter(intent); 
		
		if (adapter==null) {
			finish();
		}
		else {
			setListAdapter(adapter);
		}
	}
	
	public void onListItemClick(ListView parent, View v, int position,
									long id) {
		selection.setText(items.get(position).toString());
	}
		
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		menu.add(Menu.NONE, LOCAL_SEARCH_ID, Menu.NONE, "Local Search")
						.setIcon(android.R.drawable.ic_search_category_default);
		menu.add(Menu.NONE, GLOBAL_SEARCH_ID, Menu.NONE, "Global Search")
						.setIcon(R.drawable.search)
						.setAlphabeticShortcut(SearchManager.MENU_KEY);
	
		return(super.onCreateOptionsMenu(menu));
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
			case LOCAL_SEARCH_ID:
				onSearchRequested(); 
				return(true);
			
			case GLOBAL_SEARCH_ID:
				startSearch(null, false, null, true); 
				return(true);
		}

		return(super.onOptionsItemSelected(item));
	}
}